import { Component } from '@a11d/lit';
import { DialogActionKey } from '@a11d/lit-application';
import { SlotController } from '@3mo/slot-controller';
import '@3mo/localization';
export declare const enum DialogSize {
    Large = "large",
    Medium = "medium",
    Small = "small"
}
/**
 * @element mo-dialog
 *
 * @attr open
 * @attr heading
 * @attr size
 * @attr blocking
 * @attr primaryOnEnter
 * @attr manualClose
 * @attr primaryButtonText
 * @attr secondaryButtonText
 * @attr scrimClickAction
 * @attr preventCancellationOnEscape
 * @attr preventCancellationOnEscape
 * @attr poppable
 * @attr boundToWindow
 *
 * @slot - Content of the dialog
 * @slot primaryAction - Primary action of the dialog
 * @slot secondaryAction - Secondary action of the dialog
 * @slot header - Header of the dialog
 * @slot footer - Footer of the dialog
 *
 * @cssprop --mo-dialog-heading-color - Color of the dialog heading
 * @cssprop --mo-dialog-content-color - Color of the dialog content
 * @cssprop --mo-dialog-divider-color - Color of the dialog divider
 * @cssprop --mo-dialog-scrim-color - Color of the dialog scrim
 * @cssprop --mo-dialog-scrim-color - Color of the dialog scrim
 * @cssprop --mo-dialog-divider-color - Color of the dialog divider
 * @cssprop --mo-dialog-height - Height of the dialog
 * @cssprop --mo-dialog-width - Width of the dialog
 * @cssprop --mo-dialog-heading-line-height - Line height of the dialog heading
 *
 * @i18n "Close"
 *
 * @fires dialogHeadingChange - Dispatched when the dialog heading changes
 * @fires requestPopup - Dispatched when the dialog is requested to be popped up
 */
export declare class Dialog extends Component {
    static readonly executingActionAdaptersByComponent: Map<Constructor<HTMLElement>, (actionElement: HTMLElement, isExecuting: boolean) => void>;
    readonly dialogHeadingChange: EventDispatcher<string>;
    readonly requestPopup: EventDispatcher;
    open: boolean;
    heading: string;
    size: DialogSize;
    blocking: boolean;
    primaryOnEnter: boolean;
    manualClose: boolean;
    primaryButtonText?: string;
    secondaryButtonText?: string;
    preventCancellationOnEscape: boolean;
    poppable: boolean;
    boundToWindow: boolean;
    executingAction?: DialogActionKey;
    readonly cancellationActionElement: HTMLElement;
    handleAction: (key: DialogActionKey) => void | Promise<void>;
    protected readonly slotController: SlotController;
    static get styles(): import("@a11d/lit").CSSResult;
    disconnected(): Promise<void>;
    private get shallHideActions();
    protected get dialogHeading(): string;
    protected get template(): import("lit-html").TemplateResult<1>;
    protected get headerSlotTemplate(): import("lit-html").TemplateResult<1>;
    protected get headerDefaultTemplate(): import("lit-html").HTMLTemplateResult;
    protected get headerOptionsTemplate(): import("lit-html").TemplateResult<1>;
    protected get contentSlotTemplate(): import("lit-html").TemplateResult<1>;
    protected get contentDefaultTemplate(): import("lit-html").HTMLTemplateResult;
    protected get footerSlotTemplate(): import("lit-html").TemplateResult<1>;
    protected get footerDefaultTemplate(): import("lit-html").HTMLTemplateResult;
    protected get primaryActionSlotTemplate(): import("lit-html").TemplateResult<1>;
    protected get primaryActionDefaultTemplate(): import("lit-html").HTMLTemplateResult;
    get primaryActionElement(): HTMLElement | undefined;
    protected get secondaryActionSlotTemplate(): import("lit-html").TemplateResult<1>;
    protected get secondaryActionDefaultTemplate(): import("lit-html").HTMLTemplateResult;
    get secondaryActionElement(): HTMLElement | undefined;
}
declare global {
    interface HTMLElementTagNameMap {
        'mo-dialog': Dialog;
    }
}
//# sourceMappingURL=Dialog.d.ts.map