import { Component } from '@a11d/lit';
import { PopoverPlacement } from './PopoverPlacement.js';
import { PopoverController } from './PopoverController.js';
import { PopoverAlignment } from './PopoverAlignment.js';
import { PopoverCoordinates } from './PopoverCoordinates.js';
/**
 * @element mo-popover
 *
 * @attr fixed - Whether the popover is fixed.
 * @attr anchor - The anchor element for the popover.
 * @attr placement - The placement of the popover relative to the anchor.
 * @attr alignment - The alignment of the popover relative to the anchor.
 * @attr open - Whether the popover is open.
 * @attr openOnHover - Whether the popover should open on hover.
 * @attr openOnFocus - Whether the popover should open on focus.
 * @attr coordinates - The coordinates of the popover.
 *
 * @slot - Default slot for popover content
 *
 * @fires openChange - Fired when the popover is opened or closed.
 */
export declare class Popover extends Component {
    readonly openChange: EventDispatcher<boolean>;
    fixed: boolean;
    coordinates?: PopoverCoordinates;
    anchor: HTMLElement;
    placement: PopoverPlacement;
    alignment: PopoverAlignment;
    open: boolean;
    openOnHover?: boolean;
    openOnFocus?: boolean;
    protected readonly popoverController: PopoverController;
    setOpen(open: boolean): void;
    static get translationStyles(): import("@a11d/lit").CSSResult;
    static get styles(): import("@a11d/lit").CSSResult;
    protected get template(): import("lit-html").TemplateResult<1>;
}
//# sourceMappingURL=Popover.d.ts.map