import { LanguageCode } from './LanguageCode.js';
type Dictionary = Map<string, string | Array<string>>;
type ExtractProperties<T extends string> = T extends `${string}${'${'}${infer P}${'}'}${infer Rest}` ? P | ExtractProperties<Rest> : never;
type ExtractKey<TProperty extends string> = TProperty extends `${infer Key}:${string}` ? Key : TProperty;
type ExtractType<T extends string> = T extends `${string}:${infer Type}:${string}` ? GetMatchedType<Type> : T extends `${string}:${infer Type}` ? GetMatchedType<Type> : GetMatchedType<''>;
type GetMatchedType<T extends string> = T extends keyof LocalizationFormatterTypeMap ? LocalizationFormatterTypeMap[T] : string;
interface LocalizationFormatterTypeMap {
    [Localizer.pluralityIdentityType]: number;
    'string': string;
    'number': number;
    'Date': Date;
    '': string;
}
type LocalizationParameters<T extends string> = {
    [P in ExtractProperties<T> as ExtractKey<P>]: ExtractType<P>;
};
export declare class Localizer {
    static readonly defaultLanguage = LanguageCode.English;
    static readonly pluralityIdentityType = "pluralityNumber";
    static readonly languageChange: EventDispatcher<LanguageCode>;
    static get currentLanguage(): LanguageCode;
    static set currentLanguage(value: LanguageCode);
    private static readonly languageCodeStorage;
    private static readonly dictionariesByLanguageCode;
    private static readonly regex;
    static register(languageCode: LanguageCode, dictionary: Dictionary | Record<string, string | Array<string>>): void;
    static get currentLanguageDictionary(): Dictionary | undefined;
    static localize<T extends string>(key: T, parameters?: LocalizationParameters<T>): string;
    static matchLocalizationParameters(key: string): {
        group: string;
        key: string | undefined;
        type: string | undefined;
    }[];
    static getLocalization<T extends string>(key: T, parameters?: LocalizationParameters<T>): string;
    static getLocalizationParameter(key: string, parameter: string): void;
}
declare global {
    var t: typeof Localizer.localize;
}
export {};
//# sourceMappingURL=Localizer.d.ts.map